// src/functions/get-overflow-px.ts
function getOverflowPx(chart, textIndicator) {
  const dom = chart.getDom();
  const textsElements = Array.from(dom.getElementsByTagName("text"));
  const labelElements = textsElements.filter(
    (item) => item.textContent?.includes(textIndicator)
  );
  const {
    right: containerRight,
    left: containerLeft,
    width: containerWidth
  } = dom.getBoundingClientRect();
  let maxLeftPadding = 0, maxRightPadding = 0;
  const halfOfGridWidth = containerWidth / 2;
  for (let i = 0; i < labelElements.length; i++) {
    const { left, right, width } = labelElements[i].getBoundingClientRect();
    if (width > halfOfGridWidth || width > halfOfGridWidth) continue;
    if (right > containerRight) {
      const diff = right - containerRight;
      if (maxRightPadding < diff) maxRightPadding = diff;
    }
    if (left < containerLeft) {
      const diff = containerLeft - left;
      if (maxLeftPadding < diff) maxLeftPadding = diff;
    }
  }
  return {
    right: Math.ceil(maxRightPadding),
    left: Math.ceil(maxLeftPadding)
  };
}

// src/functions/reposition-grid.ts
function repositionGrid(chart, defaultGrid, textIndicator) {
  const { right, left } = getOverflowPx(chart, textIndicator);
  defaultGrid.right += right;
  defaultGrid.left += left;
  if (!(right || left)) return;
  const currentGrid = chart.getOption().grid[0];
  const setGrid = (grid) => {
    chart.setOption({ grid }, { lazyUpdate: true, silent: true });
  };
  if (currentGrid.right < defaultGrid.right && currentGrid.left < defaultGrid.left) {
    setGrid(defaultGrid);
  } else {
    currentGrid.right += right;
    currentGrid.left += left;
    setGrid(currentGrid);
  }
}
export {
  getOverflowPx,
  repositionGrid
};
